==> bizext.php7.0.zip: bizext/lib/spout/Writer/Exception/WriterException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cP+8IuC6K+DZsrQHrufoQWyuRCM7opwWDJl8R9DqTEADAdSUIca6Kl0uCVzH0i15EY8C3a/Ii
9o/RZYZ06cWktOpMxZ+W+1yhRgk0PYmQlZICPGTD2jbGi1pugaZ8+stzvVLY0E9HOOtVqQiqy9kt
TGemrLv/2ZMV1BL4RkjGV4g3g0YiMw2yZBqhCOvo8dqJVnOQuPxS7Fr8sVp3yMSpyHbtcPGdn0Nd
DvKp+AjW7/Uxdj0+g679MLps7sDxlO0YeVolJap6MWkhWOioazSCw+JN5NVLGvgwhPev8fLwpS0Q
9AYAw1+otmEQa39JrYUnS5VdSvSr2VbDXz5kJozYQovECrat6uNdL5reuMw4HGNhGsfRgxTAS058
4giDc8HI6e9xC3yP2WO7+zoF2fSPCFr/+vRgbdD5THmoT0vTy9DPwH2M/Qd2GDOA5KDPGms1Okip
jGViU8o6HLNbDzwGatsnAHnxFyNEHGj5rU6rLvvDwidWdl33r2Pqqj7WzEgOrzSsJcZE8oycMAmh
+6kwTsiwwZz1pt9MyUDdE1qD8mHLxm7E1z7Kvg/wHei69YYMad08D28KkbYXELMff5PMQHSsJ7si
mypNGWh7RGhoWdAeKibShcBsCtORzsPgbRgFXyyi0efHOKg8EGfLP2BMbirZXphDrw6CqXprgGt+
Kh6ls+OnYHgzZKoUYw1rV7S37fuSx1nE4A14EwnEdBfIFKQWjKZY0bRw0uJmAm8/nkZ6XDv24CGU
bkEORJH5X8TYnpd/UTLxdlqTMZlQrzQRRqg1QPMkU0Fgs+CircuY1cYmaq7TskLuE4hMV3aUZpdX
s4Rzm4WmghmgExvhZtE3pHjKl0q7vVLaEwq0UuJ82rW465ffR1ZNqoQI69XyskjNOHp+rpxErlNf
2RG2AKQv1av/kvt7OVZlsYyh1f/Nos3aKM5lMgW+WqfmyUgyA4LijkgQLmYiwGro+wzWfyBIlvId
8EKYOypoHoiv6DJtNw73rWSa9hQVNEhJga3+l6d8mB1++xH3UFyRTQ2x+4qzkZw6YukvSMR0HOWe
gLw9TDKSICj70jPCQWR68r+ZsGZDTEx2yx8pSmuM2S50PyVIHH0Y6fJkNCHWBq/qAHjff0piKzHb
Hpdx9uU1L/Y6opIZstt0b4jFYUlg2i3ImSdIUDPyvJ6RIgZ3VjT3UITq5Qvk3Rf52RsnaKGfh0fF
DeaHHtdBkfxgZST4VaQGGjsHuYZCI93lKhxc5DhhDvvgxssU8b27oxgCRXFwktjTWoSEOoMNtrIs
smmrQhHgBdlgO543VmUbq6u2cW1POwYgN8sHf8roTy69wMAw5IQg/uuqm2sEJd9Gn3WqwunBYeo6
sUIFFu3X0KPiYNbQRZi9p6nt5+ByxfkHuroOW6pJsJ1n0NvYTfDOxXqLTfAXfPDPzGlw51XGUJ5F
Avd8aQLoKBROVmJy

==> bizext.php7.1.zip: bizext/lib/spout/Writer/Exception/WriterException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPpKTii5wvGRsjwWduiu5P+n+lD4QAkO4dC439ynzRGA3uiDePnNGMcnp3e1BssqaMFZoIPXf
DgCrs8MKmEQai0tuQ6Jw2QPCOyh+pG8PVunk3FK6kHOsfi82yTjWTKCLPdRp4HribYSKIMsdXBwj
/4u59el0/2DuxUMDkNe6N2ZrgqxBveqQpje5JD42Njza2BAr/Dsn9FBcSQJV39uQe6munkA1fkmh
8iQ0juFjI5iGMA6MKI0KXpI2kAIgAbKF1/ZO1Ek+OQS+LgGq3J+Xhf+jjll+9ONKDtcfiiRrEymQ
I9JGocTqA6XtBKt7CUVajIpKywybfbfaCC8hMzvUGp2pliWFfn/sNpjsmcfdSOoCOZ4NlHNKyumj
B4iW0NdK9PpICj2ib/28HzMDb5xERK2uNG85olw5ZimCV4yPNh4FiTB5x4TeeAaryVSrm0XPJKtl
JaOQLQMIDjKEBoqeja8dooV+fkpEpYsQGYvy57BlBvVmq4Mty1Ho3ReMUCLFKveYxq7NPv83m0QB
dCW3hxZ2xqqAhilyKUSSffidgCWrufRVBUpTNFWuWL5dmOAp5iKk4p4TM47fBMhMnKzGL0n9gd3r
sD2KD+Yc/u9aVrOsqxIv81pxbh2RkX+2MlwZ/lSSqbx3PIxYlfTni6Ltnc7FEcEHQ5AFNCO3OkBp
DCOwlPvQ+1k0vH51l4cHwQonY/pi+N03mVlHwXC0/51/9ckhvRlfiZzYbbVubDt73gTt7wl4+RJw
hCtmQiEWt6GmST6qc9zg2xQVZdZBZGXsoIPcY9WlO+8YnzNCBfx5pKgj+kVAvkj+SWAxeGSBfYF8
+kZnhUMGRYk/xmfUmOzBZxxsHW2jMldpTMScWOVVUyVmw2gTMuSH3NSz4fWevujwBnKSWNEInx+D
CCfTH5ueNbCTjMp50Ze=
